@@ -169,7 +169,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="product-list")
 
@@ -294,7 +299,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="topic-list")
 
@@ -365,7 +375,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="component-list")
 
@@ -449,7 +464,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="component-file-list")
 
@@ -469,7 +489,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="file-list")
 
@@ -477,6 +502,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("id")
     p.set_defaults(command="file-show")
 
+    p = subparsers.add_parser(
+        "file-content", help="Show content of a file.", parents=[base_parser]
+    )
+    p.add_argument("id")
+    p.set_defaults(command="file-content")
+
     p = subparsers.add_parser(
         "file-delete", help="Delete a file.", parents=[base_parser]
     )
@@ -488,10 +519,22 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=10)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="job-list")
 
+    p = subparsers.add_parser("job-search", help="Search for jobs.", parents=[base_parser])
+    p.add_argument("--sort", default="-created_at")
+    p.add_argument("--limit", default=10)
+    p.add_argument("--offset", default=0)
+    p.add_argument("--query", help="Query language dsl", required=True)
+    p.set_defaults(command="job-search")
+
     p = subparsers.add_parser("job-show", help="Show a job.", parents=[base_parser])
     p.add_argument("id")
     p.set_defaults(command="job-show")
@@ -546,13 +589,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("--target", required=True, help="Destination file path.")
     p.set_defaults(command="job-download-file")
 
-    p = subparsers.add_parser(
-        "job-show-file", help="Show a job file.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--file-id", required=True)
-    p.set_defaults(command="job-show-file")
-
     p = subparsers.add_parser(
         "job-list-file", help="List files attached to a job.", parents=[base_parser]
     )
@@ -564,13 +600,6 @@ def parse_arguments(args, environment={}):
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="job-list-file")
 
-    p = subparsers.add_parser(
-        "job-delete-file", help="Delete a job file.", parents=[base_parser]
-    )
-    p.add_argument("id")
-    p.add_argument("--file-id", required=True)
-    p.set_defaults(command="job-delete-file")
-
     p = subparsers.add_parser(
         "job-add-key-value", help="Job add key/value.", parents=[base_parser]
     )
@@ -593,7 +622,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="remoteci-list")
 
@@ -715,7 +749,12 @@ def parse_arguments(args, environment={}):
     p.add_argument("--sort", default="-created_at")
     p.add_argument("--limit", default=50)
     p.add_argument("--offset", default=0)
-    p.add_argument("--where", help="Optional filter criteria", required=False)
+    p.add_argument(
+        "--where",
+        help="Optional filter criteria",
+        default="state:active",
+        required=False,
+    )
     p.add_argument("--query", help="Query language dsl", required=False)
     p.set_defaults(command="pipeline-list")
 
@@ -746,6 +785,15 @@ def parse_arguments(args, environment={}):
     p.add_argument("--offset", default=0)
     p.set_defaults(command="pipeline-show-jobs")
 
+    p = subparsers.add_parser(
+        "download-pull-secret",
+        help="Download pull secret associated with a topic.",
+        parents=[base_parser],
+    )
+    p.add_argument("--topic", required=True)
+    p.add_argument("--destination", required=True)
+    p.set_defaults(command="download-pull-secret")
+
     args = parser.parse_args(args)
 
     if "command" not in args:
