@@ -16,14 +16,20 @@
 
 from dciclient.v1.api import file as dci_file
 from dciclient.v1.api import job
+from dciclient.v1.utils import active_string, get_search_params, get_es_search_params
 
 
 def list(context, args):
-    params = {k: getattr(args, k) for k in ["sort", "limit", "offset", "where"]}
+    params = get_search_params(args)
     params["embed"] = "topic,remoteci,team"
     return job.list(context, **params)
 
 
+def search(context, args):
+    params = get_es_search_params(args)
+    return job.search(context, **params)
+
+
 def show(context, args):
     return job.get(context, id=args.id)
 
@@ -32,24 +38,32 @@ def delete(context, args):
     return job.delete(context, id=args.id, etag=args.etag)
 
 
+def update(context, args):
+    params = {
+        k: getattr(args, k)
+        for k in [
+            "comment",
+            "status",
+            "state",
+            "tags",
+            "status_reason",
+            "configuration",
+            "name",
+            "url",
+        ]
+    }
+
+    job_info = job.get(context, args.id)
+    params["etag"] = job_info.json()["job"]["etag"]
+    params["state"] = active_string(params["state"])
+    return job.update(context, id=args.id, **params)
+
+
 def list_results(context, args):
     params = {k: getattr(args, k) for k in ["sort", "limit", "offset", "id"]}
     return job.list_results(context, **params)
 
 
-def attach_issue(context, args):
-    return job.attach_issue(context, id=args.id, url=args.url)
-
-
-def unattach_issue(context, args):
-    return job.unattach_issue(context, id=args.id, issue_id=args.issue_id)
-
-
-def list_issues(context, args):
-    params = {k: getattr(args, k) for k in ["sort", "limit", "offset", "id", "where"]}
-    return job.list_issues(context, **params)
-
-
 def output(context, args):
     result = job.list_jobstates(context, id=args.id, sort="created_at")
     jobstates = result.json()["jobstates"]
@@ -65,14 +79,15 @@ def output(context, args):
 
 
 def list_tests(context, args):
-    params = {k: getattr(args, k) for k in ["sort", "limit", "offset", "id", "where"]}
+    params = get_search_params(args)
+    params["id"] = args.id
     return job.list_tests(context, **params)
 
 
 def file_upload(context, args):
     params = {
         k: getattr(args, k)
-        for k in ["job_id", "name", "file_path", "jobstate_id", "test_id", "mime"]
+        for k in ["job_id", "name", "file_path", "jobstate_id", "mime"]
     }
     return dci_file.create_with_stream(context, **params)
 
@@ -82,15 +97,15 @@ def file_download(context, args):
     dci_file.download(context, **params)
 
 
-def file_show(context, args):
-    return dci_file.get(context, id=args.file_id)
-
-
 def file_list(context, args):
-    params = {k: getattr(args, k) for k in ["sort", "limit", "offset", "id", "where"]}
+    params = get_search_params(args)
+    params["id"] = args.id
     return job.list_files(context, **params)
 
 
-def file_delete(context, args):
-    dci_file.delete(context, id=args.file_id)
-    return dci_file.delete(context, id=args.file_id)
+def add_kv(context, args):
+    return job.add_kv(context, args.id, args.key, args.value)
+
+
+def delete_kv(context, args):
+    return job.delete_kv(context, args.id, args.key)
