@@ -13,7 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from dciclient.v1.shell_commands import analytic
 from dciclient.v1.shell_commands import user
 from dciclient.v1.shell_commands import team
 from dciclient.v1.shell_commands import product
@@ -23,16 +22,12 @@ from dciclient.v1.shell_commands import topic
 from dciclient.v1.shell_commands import component
 from dciclient.v1.shell_commands import file
 from dciclient.v1.shell_commands import job
-from dciclient.v1.shell_commands import test
 from dciclient.v1.shell_commands import remoteci
+from dciclient.v1.shell_commands import pipeline
 from dciclient.v1.shell_commands import purge
 
 
 command_function = {
-    "analytic-list": analytic.list,
-    "analytic-create": analytic.create,
-    "analytic-show": analytic.show,
-    "analytic-update": analytic.update,
     "user-list": user.list,
     "user-create": user.create,
     "user-show": user.show,
@@ -58,20 +53,16 @@ command_function = {
     "feeder-delete": feeder.delete,
     "feeder-reset-api-secret": feeder.reset_api_secret,
     "jobstate-show": jobstate.show,
+    "jobstate-create": jobstate.create,
     "topic-list": topic.list,
     "topic-create": topic.create,
     "topic-show": topic.show,
-    "topic-attach-team": topic.attach_team,
-    "topic-unattach-team": topic.unattach_team,
-    "topic-list-team": topic.list_team,
     "topic-update": topic.update,
     "topic-delete": topic.delete,
+    "download-pull-secret": topic.download_pull_secret,
     "component-list": component.list,
     "component-create": component.create,
     "component-show": component.show,
-    "component-attach-issue": component.attach_issue,
-    "component-unattach-issue": component.unattach_issue,
-    "component-list-issue": component.list_issues,
     "component-update": component.update,
     "component-delete": component.delete,
     "component-file-list": component.file_list,
@@ -81,40 +72,36 @@ command_function = {
     "component-file-delete": component.file_delete,
     "file-list": file.list,
     "file-show": file.show,
+    "file-content": file.content,
     "file-delete": file.delete,
     "job-list": job.list,
     "job-show": job.show,
     "job-delete": job.delete,
     "job-results": job.list_results,
-    "job-attach-issue": job.attach_issue,
-    "job-unattach-issue": job.unattach_issue,
-    "job-list-issue": job.list_issues,
     "job-output": job.output,
-    "job-list-test": job.list_tests,
     "job-upload-file": job.file_upload,
     "job-download-file": job.file_download,
-    "job-show-file": job.file_show,
     "job-list-file": job.file_list,
-    "job-delete-file": job.file_delete,
-    "test-list": test.list,
-    "test-create": test.create,
-    "test-update": test.update,
-    "test-delete": test.delete,
-    "test-show": test.show,
+    "job-update": job.update,
+    "job-search": job.search,
+    "job-add-key-value": job.add_kv,
+    "job-delete-key-value": job.delete_kv,
     "remoteci-list": remoteci.list,
     "remoteci-create": remoteci.create,
     "remoteci-update": remoteci.update,
     "remoteci-delete": remoteci.delete,
     "remoteci-show": remoteci.show,
     "remoteci-get-data": remoteci.get_data,
-    "remoteci-attach-test": remoteci.attach_test,
-    "remoteci-unattach-test": remoteci.unattach_test,
-    "remoteci-list-test": remoteci.list_test,
     "remoteci-attach-user": remoteci.attach_user,
     "remoteci-unattach-user": remoteci.unattach_user,
     "remoteci-list-user": remoteci.list_user,
     "remoteci-reset-api-secret": remoteci.reset_api_secret,
-    "remoteci-refresh-keys": remoteci.refresh_keys,
+    "pipeline-create": pipeline.create,
+    "pipeline-show": pipeline.show,
+    "pipeline-list": pipeline.list,
+    "pipeline-delete": pipeline.delete,
+    "pipeline-update": pipeline.update,
+    "pipeline-show-jobs": pipeline.get_jobs,
     "purge": purge.purge,
 }
 
