@@ -12,13 +12,6 @@ DCI_DB_DIR="$(cd "$(dirname "$0")/.." && pwd)/$DCI_DB_DIR"
 # if the database is already running we do not want to run this script
 [ ! -z "$DISABLE_DB_START" ] &&exit 0
 
-PLATFORM=$(awk -F'=' '/^ID=/ { print $2 }' /etc/os-release)
-VERSION_ID=$(awk -F'=' '/^VERSION_ID=/ { print $2 }' /etc/os-release)
-
-if [[ ( "${PLATFORM//\"}" == rhel || "${PLATFORM//\"}" == centos ) ]] && (( ${VERSION_ID//\"} < 8 )); then
-    source /opt/rh/rh-postgresql96/enable
-fi
-
 # checks if pg_ctl command exists
 type "pg_ctl"
 
